==> youtrack-api-1.0.0-rc332477668-sources.jar: org/llorllale/youtrack/api/Projects.java <==
/*
 * Copyright 2017 George Aristy
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.llorllale.youtrack.api;

import java.io.IOException;
import java.util.Optional;
import java.util.stream.Stream;

import org.llorllale.youtrack.api.session.Session;
import org.llorllale.youtrack.api.session.UnauthorizedException;

/**
 * Fetches {@link Project projects} from the YouTrack server.
 * @author George Aristy (george.aristy@gmail.com)
 * @since 0.4.0
 */
public interface Projects {
  /**
   * Returns a {@link Stream} with all accessible {@link Project projects} by the user's 
   * {@link Session}.
   * @return a {@link Stream} with all accessible {@link Project projects} by the user's 
   *     {@link Session}
   * @throws IOException if the server is unavailable
   * @throws UnauthorizedException if the user's {@link Session} is not authorized to access this
   *     resource
   * @since 0.4.0
   */
  Stream<Project> stream() throws IOException, UnauthorizedException;

  /**
   * Returns the {@link Project} with the given {@code id}, if any.
   * @param id the project's {@link Project#id() id}
   * @return the {@link Project} with the given {@code id}, if any
   * @throws IOException if the server is unavailable
   * @throws UnauthorizedException if the user's {@link Session} is not authorized to perform this
   *     operation
   * @since 0.6.0
   */
  Optional<Project> get(String id) throws IOException, UnauthorizedException;
}

==> youtrack-api-1.1.0-rc23-sources.jar: org/llorllale/youtrack/api/Projects.java <==
/*
 * Copyright 2017 George Aristy
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.llorllale.youtrack.api;

import java.io.IOException;
import java.util.Optional;
import java.util.stream.Stream;

import org.llorllale.youtrack.api.session.Login;
import org.llorllale.youtrack.api.session.UnauthorizedException;

/**
 * Fetches {@link Project projects} from the YouTrack server.
 * @author George Aristy (george.aristy@gmail.com)
 * @since 0.4.0
 */
public interface Projects {
  /**
   * Returns a {@link Stream} with all accessible {@link Project projects} by the user's 
   * {@link Login}.
   * @return a {@link Stream} with all accessible {@link Project projects} by the user's 
   *     {@link Login}
   * @throws IOException if the server is unavailable
   * @throws UnauthorizedException if the user's {@link Login} is not authorized to access this
   *     resource
   * @since 0.4.0
   */
  Stream<Project> stream() throws IOException, UnauthorizedException;

  /**
   * Returns the {@link Project} with the given {@code id}, if any.
   * @param id the project's {@link Project#id() id}
   * @return the {@link Project} with the given {@code id}, if any
   * @throws IOException if the server is unavailable
   * @throws UnauthorizedException if the user's {@link Login} is not authorized to perform this
   *     operation
   * @since 0.6.0
   */
  Optional<Project> get(String id) throws IOException, UnauthorizedException;

  /**
   * Create a new {@link Project}.
   * @param id unique identifier of the project to be created. This short name will be used as
   *    prefix in issue IDs for this project.
   * @param name unique, full name of the new project.
   * @param leader user to be assigned as the project's leader.
   * @return the newly-created project
   * @throws IOException if the server is unavailable
   * @throws UnauthorizedException if the user's {@link Login} is not authorized to perform this
   *     operation
   * @since 1.1.0
   */
  Project create(String id, String name, User leader) throws IOException, UnauthorizedException;
}
